/**
 * TheCitadelofRicks
 *
 * Copyright 2019  <seil0@mosad.xyz>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

package org.mosad.thecitadelofricks.hsoparser

import org.jsoup.Jsoup
import org.mosad.thecitadelofricks.Meal
import org.mosad.thecitadelofricks.MensaWeek

class MensaParser {

    /**
     * returns the mensa menu for the a week
     */
    fun getMensaMenu(menuLink: String): MensaWeek {
        val mealWeekList = MensaWeek()
        val menuHTML = Jsoup.connect(menuLink).get()

        menuHTML.select("#speiseplan-tabs").select("div.tab-content").select("div.menu-tagesplan")
            .forEachIndexed { dayIndex, day ->
                val strDay = day.select("h3").text()

                day.select("div.menu-info").forEachIndexed { mealIndex, meal ->
                    val heading = day.select("h4")[mealIndex].text()
                    val parts = ArrayList(meal.html().substringBefore("<br>\n").replace("\n", "").split("<br>"))
                    val additives = meal.select("span.show-with-allergenes").text()
                    parts.removeIf { x -> x.isEmpty() || x.isBlank() }

                    mealWeekList.days[dayIndex].meals.add(Meal(strDay, heading, parts, additives))
                }

            }

        return mealWeekList
    }

    /**
     * return the link of the next weeks menus
     * @param menuLink the current weeks menus link
     */
    fun getMenuLinkNextWeek(menuLink: String): String {
        val menuHTML = Jsoup.connect(menuLink).get()

        return "https://www.swfr.de" + menuHTML.select("#speiseplan-tabs").select("a.next-week").attr("href")
    }

}